==> google_cloud_securitycenter-1.13.0-py2.py3-none-any.whl: google/cloud/securitycenter_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .access import Access, Geolocation
from .asset import Asset
from .bigquery_export import BigQueryExport
from .compliance import Compliance
from .connection import Connection
from .contact_details import Contact, ContactDetails
from .container import Container
from .exfiltration import ExfilResource, Exfiltration
from .external_system import ExternalSystem
from .file import File
from .finding import Finding
from .folder import Folder
from .iam_binding import IamBinding
from .indicator import Indicator
from .kubernetes import Kubernetes
from .label import Label
from .mitre_attack import MitreAttack
from .mute_config import MuteConfig
from .notification_config import NotificationConfig
from .notification_message import NotificationMessage
from .organization_settings import OrganizationSettings
from .process import EnvironmentVariable, Process
from .resource import Resource
from .run_asset_discovery_response import RunAssetDiscoveryResponse
from .security_marks import SecurityMarks
from .securitycenter_service import (
    BulkMuteFindingsRequest,
    BulkMuteFindingsResponse,
    CreateBigQueryExportRequest,
    CreateFindingRequest,
    CreateMuteConfigRequest,
    CreateNotificationConfigRequest,
    CreateSourceRequest,
    DeleteBigQueryExportRequest,
    DeleteMuteConfigRequest,
    DeleteNotificationConfigRequest,
    GetBigQueryExportRequest,
    GetMuteConfigRequest,
    GetNotificationConfigRequest,
    GetOrganizationSettingsRequest,
    GetSourceRequest,
    GroupAssetsRequest,
    GroupAssetsResponse,
    GroupFindingsRequest,
    GroupFindingsResponse,
    GroupResult,
    ListAssetsRequest,
    ListAssetsResponse,
    ListBigQueryExportsRequest,
    ListBigQueryExportsResponse,
    ListFindingsRequest,
    ListFindingsResponse,
    ListMuteConfigsRequest,
    ListMuteConfigsResponse,
    ListNotificationConfigsRequest,
    ListNotificationConfigsResponse,
    ListSourcesRequest,
    ListSourcesResponse,
    RunAssetDiscoveryRequest,
    SetFindingStateRequest,
    SetMuteRequest,
    UpdateBigQueryExportRequest,
    UpdateExternalSystemRequest,
    UpdateFindingRequest,
    UpdateMuteConfigRequest,
    UpdateNotificationConfigRequest,
    UpdateOrganizationSettingsRequest,
    UpdateSecurityMarksRequest,
    UpdateSourceRequest,
)
from .source import Source
from .vulnerability import Cve, Cvssv3, Reference, Vulnerability

__all__ = (
    "Access",
    "Geolocation",
    "Asset",
    "BigQueryExport",
    "Compliance",
    "Connection",
    "Contact",
    "ContactDetails",
    "Container",
    "ExfilResource",
    "Exfiltration",
    "ExternalSystem",
    "File",
    "Finding",
    "Folder",
    "IamBinding",
    "Indicator",
    "Kubernetes",
    "Label",
    "MitreAttack",
    "MuteConfig",
    "NotificationConfig",
    "NotificationMessage",
    "OrganizationSettings",
    "EnvironmentVariable",
    "Process",
    "Resource",
    "RunAssetDiscoveryResponse",
    "SecurityMarks",
    "BulkMuteFindingsRequest",
    "BulkMuteFindingsResponse",
    "CreateBigQueryExportRequest",
    "CreateFindingRequest",
    "CreateMuteConfigRequest",
    "CreateNotificationConfigRequest",
    "CreateSourceRequest",
    "DeleteBigQueryExportRequest",
    "DeleteMuteConfigRequest",
    "DeleteNotificationConfigRequest",
    "GetBigQueryExportRequest",
    "GetMuteConfigRequest",
    "GetNotificationConfigRequest",
    "GetOrganizationSettingsRequest",
    "GetSourceRequest",
    "GroupAssetsRequest",
    "GroupAssetsResponse",
    "GroupFindingsRequest",
    "GroupFindingsResponse",
    "GroupResult",
    "ListAssetsRequest",
    "ListAssetsResponse",
    "ListBigQueryExportsRequest",
    "ListBigQueryExportsResponse",
    "ListFindingsRequest",
    "ListFindingsResponse",
    "ListMuteConfigsRequest",
    "ListMuteConfigsResponse",
    "ListNotificationConfigsRequest",
    "ListNotificationConfigsResponse",
    "ListSourcesRequest",
    "ListSourcesResponse",
    "RunAssetDiscoveryRequest",
    "SetFindingStateRequest",
    "SetMuteRequest",
    "UpdateBigQueryExportRequest",
    "UpdateExternalSystemRequest",
    "UpdateFindingRequest",
    "UpdateMuteConfigRequest",
    "UpdateNotificationConfigRequest",
    "UpdateOrganizationSettingsRequest",
    "UpdateSecurityMarksRequest",
    "UpdateSourceRequest",
    "Source",
    "Cve",
    "Cvssv3",
    "Reference",
    "Vulnerability",
)

==> google_cloud_securitycenter-1.20.0-py2.py3-none-any.whl: google/cloud/securitycenter_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .access import Access, Geolocation, ServiceAccountDelegationInfo
from .asset import Asset
from .bigquery_export import BigQueryExport
from .compliance import Compliance
from .connection import Connection
from .contact_details import Contact, ContactDetails
from .container import Container
from .database import Database
from .effective_security_health_analytics_custom_module import (
    EffectiveSecurityHealthAnalyticsCustomModule,
)
from .exfiltration import ExfilResource, Exfiltration
from .external_system import ExternalSystem
from .file import File
from .finding import Finding
from .folder import Folder
from .iam_binding import IamBinding
from .indicator import Indicator
from .kernel_rootkit import KernelRootkit
from .kubernetes import Kubernetes
from .label import Label
from .mitre_attack import MitreAttack
from .mute_config import MuteConfig
from .notification_config import NotificationConfig
from .notification_message import NotificationMessage
from .organization_settings import OrganizationSettings
from .process import EnvironmentVariable, Process
from .resource import Resource
from .run_asset_discovery_response import RunAssetDiscoveryResponse
from .security_health_analytics_custom_config import CustomConfig
from .security_health_analytics_custom_module import SecurityHealthAnalyticsCustomModule
from .security_marks import SecurityMarks
from .securitycenter_service import (
    BulkMuteFindingsRequest,
    BulkMuteFindingsResponse,
    CreateBigQueryExportRequest,
    CreateFindingRequest,
    CreateMuteConfigRequest,
    CreateNotificationConfigRequest,
    CreateSecurityHealthAnalyticsCustomModuleRequest,
    CreateSourceRequest,
    DeleteBigQueryExportRequest,
    DeleteMuteConfigRequest,
    DeleteNotificationConfigRequest,
    DeleteSecurityHealthAnalyticsCustomModuleRequest,
    GetBigQueryExportRequest,
    GetEffectiveSecurityHealthAnalyticsCustomModuleRequest,
    GetMuteConfigRequest,
    GetNotificationConfigRequest,
    GetOrganizationSettingsRequest,
    GetSecurityHealthAnalyticsCustomModuleRequest,
    GetSourceRequest,
    GroupAssetsRequest,
    GroupAssetsResponse,
    GroupFindingsRequest,
    GroupFindingsResponse,
    GroupResult,
    ListAssetsRequest,
    ListAssetsResponse,
    ListBigQueryExportsRequest,
    ListBigQueryExportsResponse,
    ListDescendantSecurityHealthAnalyticsCustomModulesRequest,
    ListDescendantSecurityHealthAnalyticsCustomModulesResponse,
    ListEffectiveSecurityHealthAnalyticsCustomModulesRequest,
    ListEffectiveSecurityHealthAnalyticsCustomModulesResponse,
    ListFindingsRequest,
    ListFindingsResponse,
    ListMuteConfigsRequest,
    ListMuteConfigsResponse,
    ListNotificationConfigsRequest,
    ListNotificationConfigsResponse,
    ListSecurityHealthAnalyticsCustomModulesRequest,
    ListSecurityHealthAnalyticsCustomModulesResponse,
    ListSourcesRequest,
    ListSourcesResponse,
    RunAssetDiscoveryRequest,
    SetFindingStateRequest,
    SetMuteRequest,
    UpdateBigQueryExportRequest,
    UpdateExternalSystemRequest,
    UpdateFindingRequest,
    UpdateMuteConfigRequest,
    UpdateNotificationConfigRequest,
    UpdateOrganizationSettingsRequest,
    UpdateSecurityHealthAnalyticsCustomModuleRequest,
    UpdateSecurityMarksRequest,
    UpdateSourceRequest,
)
from .source import Source
from .vulnerability import Cve, Cvssv3, Reference, Vulnerability

__all__ = (
    "Access",
    "Geolocation",
    "ServiceAccountDelegationInfo",
    "Asset",
    "BigQueryExport",
    "Compliance",
    "Connection",
    "Contact",
    "ContactDetails",
    "Container",
    "Database",
    "EffectiveSecurityHealthAnalyticsCustomModule",
    "ExfilResource",
    "Exfiltration",
    "ExternalSystem",
    "File",
    "Finding",
    "Folder",
    "IamBinding",
    "Indicator",
    "KernelRootkit",
    "Kubernetes",
    "Label",
    "MitreAttack",
    "MuteConfig",
    "NotificationConfig",
    "NotificationMessage",
    "OrganizationSettings",
    "EnvironmentVariable",
    "Process",
    "Resource",
    "RunAssetDiscoveryResponse",
    "CustomConfig",
    "SecurityHealthAnalyticsCustomModule",
    "SecurityMarks",
    "BulkMuteFindingsRequest",
    "BulkMuteFindingsResponse",
    "CreateBigQueryExportRequest",
    "CreateFindingRequest",
    "CreateMuteConfigRequest",
    "CreateNotificationConfigRequest",
    "CreateSecurityHealthAnalyticsCustomModuleRequest",
    "CreateSourceRequest",
    "DeleteBigQueryExportRequest",
    "DeleteMuteConfigRequest",
    "DeleteNotificationConfigRequest",
    "DeleteSecurityHealthAnalyticsCustomModuleRequest",
    "GetBigQueryExportRequest",
    "GetEffectiveSecurityHealthAnalyticsCustomModuleRequest",
    "GetMuteConfigRequest",
    "GetNotificationConfigRequest",
    "GetOrganizationSettingsRequest",
    "GetSecurityHealthAnalyticsCustomModuleRequest",
    "GetSourceRequest",
    "GroupAssetsRequest",
    "GroupAssetsResponse",
    "GroupFindingsRequest",
    "GroupFindingsResponse",
    "GroupResult",
    "ListAssetsRequest",
    "ListAssetsResponse",
    "ListBigQueryExportsRequest",
    "ListBigQueryExportsResponse",
    "ListDescendantSecurityHealthAnalyticsCustomModulesRequest",
    "ListDescendantSecurityHealthAnalyticsCustomModulesResponse",
    "ListEffectiveSecurityHealthAnalyticsCustomModulesRequest",
    "ListEffectiveSecurityHealthAnalyticsCustomModulesResponse",
    "ListFindingsRequest",
    "ListFindingsResponse",
    "ListMuteConfigsRequest",
    "ListMuteConfigsResponse",
    "ListNotificationConfigsRequest",
    "ListNotificationConfigsResponse",
    "ListSecurityHealthAnalyticsCustomModulesRequest",
    "ListSecurityHealthAnalyticsCustomModulesResponse",
    "ListSourcesRequest",
    "ListSourcesResponse",
    "RunAssetDiscoveryRequest",
    "SetFindingStateRequest",
    "SetMuteRequest",
    "UpdateBigQueryExportRequest",
    "UpdateExternalSystemRequest",
    "UpdateFindingRequest",
    "UpdateMuteConfigRequest",
    "UpdateNotificationConfigRequest",
    "UpdateOrganizationSettingsRequest",
    "UpdateSecurityHealthAnalyticsCustomModuleRequest",
    "UpdateSecurityMarksRequest",
    "UpdateSourceRequest",
    "Source",
    "Cve",
    "Cvssv3",
    "Reference",
    "Vulnerability",
)
